django_cohort_analysis package
==============================

Submodules
----------

django_cohort_analysis.cohorts module
-------------------------------------

.. automodule:: django_cohort_analysis.cohorts
    :members:
    :undoc-members:
    :show-inheritance:

django_cohort_analysis.exceptions module
----------------------------------------

.. automodule:: django_cohort_analysis.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

django_cohort_analysis.metrics module
-------------------------------------

.. automodule:: django_cohort_analysis.metrics
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: django_cohort_analysis
    :members:
    :undoc-members:
    :show-inheritance:
